==> dl.php?src=linea21_1_0.zip: linea21/level/det.php <==
<?php
//////////// Check Inclusion de pages //////////// 
if (!function_exists('AuthenthificationProcess')){ 
include_once("../lib/lib_common.php");
ReloadIndex('admin');
}
////////////

if(isset($_POST['id']))	$id=$_POST['id'];
if(isset($_GET['id']))	$id=$_GET['id'];

include_once("../lib/lib_common.php"); 
$req_det= SQL_getdetlevel($id);

$result=$sql_object->DBSelect($req_det);
$current_title=$result[0]['level_name'];
$display_desc=formatText($result[0]['level_description'], '2HTML');
$display_comment=formatText(empty_none($result[0]['level_comment'], '2HTML'));
$display_range=$result[0]['level_range'];
$display_date_crea=$result[0]['level_date_crea'];
$display_last_modify=$result[0]['level_last_modify'];
$display_status=display_statut($result[0]['level_statut']);

// formattage des donnes
if(!empty($result[0]['level_visual_identity'])) {
	$complete_uri="../".$result[0]['level_visual_identity'];
	list($width, $height, $type, $attr) = getimagesize($complete_uri);
	$complete_uri="<a href=\"".$complete_uri."\" title=\"".$GLOBALS['lang']['divers']['see_visual']."\" onclick=\"displayImage('".$complete_uri."', '', ".$width.", ".$height."); return false;\">". $complete_uri."</a>";
} else $complete_uri=$GLOBALS['lang']['divers']['novisu'];


$link_det=$rub_link."&amp;todo=det&amp;id="; 
$link_mod=$rub_link."&amp;todo=mod&amp;id=";
?>
<div id="chemin">
	<ul>
		<li>
			<a href="index.php"><?php echo $GLOBALS['lang']['way']['home']; ?></a>
		</li>
		<li>
			<a href="<?php echo $rub_link; ?>"><?php echo $GLOBALS['lang']['menu']['level']; ?></a>
		</li>
		<li>
			<span><?php echo formatNavTitle($GLOBALS['lang']['level']['det']." : ".$current_title); ?></span>
		</li>
	</ul>
</div>
<!--end barre haute -->
<?php
include_once("quickicons.php");
?>
<div class="contentcontainer">
<?php
include_once($dir."/menurub.php");
?>
<div id="content">
		<h2><?php echo formatTitleh2($current_title); ?></h2>	
		<?php
		echo "\t<a href=\"".$link_mod.$id."\" title=\"".$GLOBALS['lang']['level']['mod']."\" class=\"ico_mod2\"></a>\n";
		?>
		<dl class="dl3">
		<dt><?php echo $GLOBALS['lang']['level']['description']; ?> :</dt>
		<dd><?php echo $display_desc; ?></dd>
		<dt><?php echo $GLOBALS['lang']['level']['comment']; ?> : </dt>
		<dd><?php echo $display_comment;?></dd>
		<dt><?php echo $GLOBALS['lang']['level']['visual_identity']; ?> : </dt>
		<dd><?php echo $complete_uri; ?></dd>
		<dt><?php echo $GLOBALS['lang']['divers']['range']; ?> : </dt>
		<dd><?php echo $display_range;?></dd>
		<dt><?php echo $GLOBALS['lang']['divers']['last_modify']; ?> :</dt>
		<dd><?php echo $display_last_modify;?></dd>
		<dt><?php echo $GLOBALS['lang']['divers']['date_crea']; ?> :</dt>
		<dd><?php echo $display_date_crea; ?></dd>
		<!--
		<dt><?php echo $GLOBALS['lang']['divers']['statut']; ?>  :</dt>
		<dd><?php echo $display_status;?></dd>
		-->
</dl>
</div>
<?php include_once($dir."/help.php"); ?>
</div>

==> dl.php?src=linea21_1_1.zip: linea21/level/det.php <==
<?php
//////////// Check Inclusion de pages //////////// 
if (!function_exists('AuthenthificationProcess')){ 
include_once("../lib/lib_common.php");
ReloadIndex('admin');
}
////////////

if(isset($_POST['id']))	$id=$_POST['id'];
if(isset($_GET['id']))	$id=$_GET['id'];

include_once("../lib/lib_common.php"); 
$req_det= SQL_getdetlevel($id);

$result=$sql_object->DBSelect($req_det);
$current_title=$result[0]['level_name'];
$display_desc=formatText($result[0]['level_description'], '2HTML');
$display_comment=formatText(empty_none($result[0]['level_comment'], '2HTML'));
$display_range=$result[0]['level_range'];
$display_date_crea=$result[0]['level_date_crea'];
$display_last_modify=$result[0]['level_last_modify'];
$display_status=display_statut($result[0]['level_statut']);

// formattage des données
if(!empty($result[0]['level_visual_identity'])) {
	$complete_uri="../".$result[0]['level_visual_identity'];
	list($width, $height, $type, $attr) = getimagesize($complete_uri);
	$complete_uri="<a href=\"".$complete_uri."\" title=\"".$GLOBALS['lang']['divers']['see_visual']."\" onclick=\"displayImage('".$complete_uri."', '', ".$width.", ".$height."); return false;\">". $complete_uri."</a>";
} else $complete_uri=$GLOBALS['lang']['divers']['novisu'];


$link_det=$rub_link."&amp;todo=det&amp;id="; 
$link_mod=$rub_link."&amp;todo=mod&amp;id=";
?>
<div id="chemin">
	<ul>
		<li>
			<a href="index.php"><?php echo $GLOBALS['lang']['way']['home']; ?></a>
		</li>
		<li>
			<a href="<?php echo $rub_link; ?>"><?php echo $GLOBALS['lang']['menu']['level']; ?></a>
		</li>
		<li>
			<span><?php echo formatNavTitle($GLOBALS['lang']['level']['det']." : ".$current_title); ?></span>
		</li>
	</ul>
</div>
<!--end barre haute -->
<?php
include_once("quickicons.php");
?>
<div class="contentcontainer">
<?php
include_once($dir."/menurub.php");
?>
<div id="content">
		<h2><?php echo formatTitleh2($current_title); ?></h2>	
		<?php
		echo "\t<a href=\"".$link_mod.$id."\" title=\"".$GLOBALS['lang']['level']['mod']."\" class=\"ico_mod2\"></a>\n";
		?>
		<dl class="dl3">
		<dt><?php echo $GLOBALS['lang']['level']['description']; ?> :</dt>
		<dd><?php echo $display_desc; ?></dd>
		<dt><?php echo $GLOBALS['lang']['level']['comment']; ?> : </dt>
		<dd><?php echo $display_comment;?></dd>
		<dt><?php echo $GLOBALS['lang']['level']['visual_identity']; ?> : </dt>
		<dd><?php echo $complete_uri; ?></dd>
		<dt><?php echo $GLOBALS['lang']['divers']['range']; ?> : </dt>
		<dd><?php echo $display_range;?></dd>
		<dt><?php echo $GLOBALS['lang']['divers']['last_modify']; ?> :</dt>
		<dd><?php echo $display_last_modify;?></dd>
		<dt><?php echo $GLOBALS['lang']['divers']['date_crea']; ?> :</dt>
		<dd><?php echo $display_date_crea; ?></dd>
		<!--
		<dt><?php echo $GLOBALS['lang']['divers']['statut']; ?>  :</dt>
		<dd><?php echo $display_status;?></dd>
		-->
</dl>
</div>
<?php include_once($dir."/help.php"); ?>
</div>
